g3_action_order <- list(
  # NB: Using -1 is okay, but -2 will sort incorrectly
  initial = -1L,
  report_early = 0L,
  time = 1L,
  migrate = 2L,
  predate = 3L,
  naturalmortality = 4L,
  grow = 5L,
  spawn = 6L,
  mature = 7L,
  renewal = 8L,
  straying = 9L,
  likelihood = 10L,
  report = 11L,
  age = 12L,
  quota = 13L )
